[![Codecov][codecov-badge]][codecov-link]
[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]
[![PyPI version][pypi-version]][pypi-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

# flint

<!-- SPHINX-START -->

<!-- prettier-ignore-start -->
[codecov-badge]:            https://codecov.io/gh/flint-crew/flint/graph/badge.svg?token=7ZEKJ78TBZ
[codecov-link]:             https://codecov.io/gh/flint-crew/flint
[actions-badge]:            https://github.com/flint-crew/flint/workflows/CI/badge.svg
[actions-link]:             https://github.com/flint-crew/flint/actions
[pypi-link]:                https://pypi.org/project/askap-flint/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/askap-flint
[pypi-version]:             https://img.shields.io/pypi/v/askap-flint
[rtd-badge]:                https://readthedocs.org/projects/askap-flint/badge/?version=latest
[rtd-link]:                 https://askap-flint.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->

A pirate themed ASKAP pipeline.

Yarrrr-Harrrr fiddly-dee!

<img src="_static/logo.jpeg" alt="Capn' Flint - Credit: DALLE 3" style="width:400px;"/>

## Documentation

Full documentation is provided on
[ReadtheDocs](https://askap-flint.readthedocs.io/).

## Contributions

Contributions are welcome! Please do submit a pull-request or issue if you spot
something you would like to address.

The pre-packed module may be installed from PyPi:

```bash
pip install askap-flint
```
The full set of dev tooling can be installed via:

```bash
git clone https://github.com/flint-crew/flint.git
cd flint
pip install '.[dev]'
```
